#!/bin/bash
#
# Yionel 	: contact@yionel.fr
# created	: 2011/08/27
# modified  : 2011/09/18
#
# Script "AlbumsSync" pour retailler les photos pour piwigo
# qui prend en compte si la photo est verticale ou non
# Il prend en argument le repertoire en absolu ou relatif
# ou sont stockées les images 
#
# l'envoi du fichier se fait en scp par une clé publique. Le client sera
# connu du serveur pour éviter la demande de connexion (yes/no)
#
# TODO
#  - synchroniser la gallerie
#  - prendre en compte la compression de fichier
#  - calculer le temps de retail+compression+envoi
#  - prendre en compte n album en argument
#  - prendre en compte si le répertoire existe sur le serveur
#  - prendre en compte des options -vdwpsuchxd
#  - vérifier la place disque
#  - prendre en compte un mot de passe
#  - gestion du multilangue lors du passage en python 
#  - enlever le sous domaine du server (www ou autre)
#  - lancer la synchro de la gallerie
#  - vérifier la présence de curl
#
# DID
#  + gestion des caractères spéciaux de l'album
# 
#
# Copyright (c) 2011 AlbumsSync Lionel Jamme 
# http://www.lionel-jamme.fr
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##

# configuration du serveur
server=yionel.fr # serveur ou est hébergé les images
domsub= #sous domaine de la gallerie
user=xx
wordpass=
port= # par defaut 22
cible="/home/yionel/Documents/www/img.yionel.fr/galleries"
xcompress=0 # (0/1)
debug=1	# (0/1)
version=0.2
help="copyright (c) 2011 Lionel Jamme version »$version"

# taille des images souhaité
Aw=128;  Ah=106
Bw=880;  Bh=660
Cw=4288; Ch=2848
########################################################################


# on cherche des arguments en paramètre

##

# on affine les valeurs
subdomaine=
if [ $domsub != "" ]; then subdomaine="$domsub."; fi
##

declare -a img=(JPEG PNG GIF TIFF)
dirA="thumbnail"
dirC="pwg_high"



if [ "$1" = "" ]; then
	echo "Il faut un répertoire en argument"
elif [ -d "$1" ]; then
	
	traitement=0
	album=$1
	
	# suppression du dernier / si il existe
	if [ $(echo -n $1 | tail -c 1) = / ]; then
		album=${album%/*}
	fi
	
	# on garde le dernier dossier qui est le dossier courant
	currentdir=${album##*/}
	
	cd "$1"
	
	# on filtre le nom du répertoire pour n'accepter que [a-zA-Z0-9._-] pour piwigo.
	dircible=`echo $currentdir | sed -e "y/ÀÂÄâäàÊËÈÉéèêëÎÏîïÔÖôöÛÜûüùŶŸŷÿ/AAAaaaEEEEeeeeIIiiOOooUUuuuYYyy/; s/[ \t]/_/g; s/[^0-9a-zA-Z_.-]//g"`
	if [ $dircible = "" ]; then dircible="piwigoAlbums_1"; fi
	if [ $debug -eq 1 ]; then echo "dircible=$dircible"; fi 
		
	for i in $( ls ); do
		if [ -d "$i" ]; then
			echo -n "?"
		else
			# test si le fichier est une image
			fichier=`file $i | cut -d " " -f2`
			
			ok=0
			for j in ${img[*]}; do 
				if [ "$j" = "$fichier" ]; then ok=1; fi
			done
			
			if [ $ok -eq 1 ]; then
				((traitement++));
				
				if [ $traitement -eq 1 ]; then
					dirtmp=`mktemp -d /tmp/piwigo.XXXXXX`
	
					echo "Création du répertoire $dirtmp/$dircible/$dirA"
					mkdir -p "$dirtmp/$dircible/$dirA"
					
					echo "Création du répertoire $dirtmp/$dircible/$dirC"
					mkdir -p "$dirtmp/$dircible/$dirC"
					
					echo "Traitement des images en cours :"
				fi
				identify=`identify $i`
				
				if [ $debug -eq 1 ]; then echo $identify; fi
				
				#Pourquoi cela ne marche pas ?
				#a2=`$identify -format "%w" $i`
				#b2=`$identify -format "%h" $i`
				
				a=`echo -n $identify | cut -d " " -f3 | cut -d "x" -f1`
				b=`echo -n $identify | cut -d " " -f3 | cut -d "x" -f2`
				
				if [ $a -gt $b ]; then
					A=$Aw
					B=$Bw
					C=$Cw
				else
					A=$Ah
					B=$Bh
					C=$Ch
				fi
				
				if [ $debug -eq 1 ]; then echo "convert $A $i"; fi 
				convert -resize $A $i "$dirtmp/$dircible/$dirA/TN-$i"
				if [ $debug -eq 1 ]; then echo "convert $B $i"; fi 
				convert -resize $B $i "$dirtmp/$dircible/$i"
				if [ $debug -eq 1 ]; then echo "convert $C $i"; fi 
				convert -resize $C $i "$dirtmp/$dircible/$dirC/$i"
				
				if [ $debug -eq 0 ]; then echo -n "."; fi
			fi		
		fi
	done
	
	if [ $traitement -gt 0 ]; then
		if [ $debug -eq 0 ]; then echo -n ""; fi
		
		cd $dirtmp
		echo "Archivage de $dirtmp/$dircible/"
		tar cf "$dircible.tar" "$dircible"
		
		if [ $port = "" ]; then port=22; fi
		
		echo "Envoie de $dirtmp/$dircible.tar sur le serveur $server"
		scp -P$port "$dirtmp/$dircible.tar" $user@$server:$cible
		
		echo "Désarchivage de $dircible.tar sur $server"
		ssh -p$port $user@$server "bash -c \"cd $cible;tar xf $dircible.tar;rm -f $dircible.tar\""
		
		echo "Fin de la connexion"
		echo "On lance la synchro"
		
		# on lance la synchro
		response=`curl -d "login=Valider&username=yionel&password=ujnedx12" http://$subdomaine$server/identification.php`;
		exit_status=$?;
		if [ $exit_status != 0 ]; then echo "ERR"; else echo "OK"; fi
		echo "$exit_status ==> $response"
		
		if [ $debug -eq 0 ]; then 
			echo "Supression des fichiers temporaires"
			rm -rf $dirtmp;
		fi		
	else
		echo "Aucune image à traiter pour $album"
	fi
else
	echo "$1 n'est pas un répertoire"
fi

exit 0
